<a id="types-aiobotocore-glue"></a>

# types-aiobotocore-glue

[![PyPI - types-aiobotocore-glue](https://img.shields.io/pypi/v/types-aiobotocore-glue.svg?color=blue)](https://pypi.org/project/types-aiobotocore-glue)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-glue.svg?color=blue)](https://pypi.org/project/types-aiobotocore-glue)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-glue?color=blue)](https://pypistats.org/packages/types-aiobotocore-glue)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.Glue 2.3.2](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/glue.html#Glue)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.5.14](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-glue docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_glue/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-glue](#types-aiobotocore-glue)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `Glue`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `Glue` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[glue]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[glue]'


# standalone installation
python -m pip install types-aiobotocore-glue
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-glue
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[glue]` in your environment:

```bash
python -m pip install 'types-aiobotocore[glue]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[glue]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[glue]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[glue]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[glue]` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[glue]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[glue]` in your environment:

```bash
python -m pip install 'types-aiobotocore[glue]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[glue]` in your environment:

```bash
python -m pip install 'types-aiobotocore[glue]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`GlueClient` provides annotations for `session.create_client("glue")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_glue import GlueClient

session = get_session()
async with session.create_client("glue") as client:
    client: GlueClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_glue.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_glue import GlueClient
from types_aiobotocore_glue.paginator import (
    GetClassifiersPaginator,
    GetConnectionsPaginator,
    GetCrawlerMetricsPaginator,
    GetCrawlersPaginator,
    GetDatabasesPaginator,
    GetDevEndpointsPaginator,
    GetJobRunsPaginator,
    GetJobsPaginator,
    GetPartitionIndexesPaginator,
    GetPartitionsPaginator,
    GetResourcePoliciesPaginator,
    GetSecurityConfigurationsPaginator,
    GetTableVersionsPaginator,
    GetTablesPaginator,
    GetTriggersPaginator,
    GetUserDefinedFunctionsPaginator,
    ListRegistriesPaginator,
    ListSchemaVersionsPaginator,
    ListSchemasPaginator,
)

session = get_session()
async with session.create_client("glue") as client:
    client: GlueClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        get_classifiers_paginator: GetClassifiersPaginator = client.get_paginator("get_classifiers")
        get_connections_paginator: GetConnectionsPaginator = client.get_paginator("get_connections")
        get_crawler_metrics_paginator: GetCrawlerMetricsPaginator = client.get_paginator("get_crawler_metrics")
        get_crawlers_paginator: GetCrawlersPaginator = client.get_paginator("get_crawlers")
        get_databases_paginator: GetDatabasesPaginator = client.get_paginator("get_databases")
        get_dev_endpoints_paginator: GetDevEndpointsPaginator = client.get_paginator("get_dev_endpoints")
        get_job_runs_paginator: GetJobRunsPaginator = client.get_paginator("get_job_runs")
        get_jobs_paginator: GetJobsPaginator = client.get_paginator("get_jobs")
        get_partition_indexes_paginator: GetPartitionIndexesPaginator = client.get_paginator("get_partition_indexes")
        get_partitions_paginator: GetPartitionsPaginator = client.get_paginator("get_partitions")
        get_resource_policies_paginator: GetResourcePoliciesPaginator = client.get_paginator("get_resource_policies")
        get_security_configurations_paginator: GetSecurityConfigurationsPaginator = client.get_paginator("get_security_configurations")
        get_table_versions_paginator: GetTableVersionsPaginator = client.get_paginator("get_table_versions")
        get_tables_paginator: GetTablesPaginator = client.get_paginator("get_tables")
        get_triggers_paginator: GetTriggersPaginator = client.get_paginator("get_triggers")
        get_user_defined_functions_paginator: GetUserDefinedFunctionsPaginator = client.get_paginator("get_user_defined_functions")
        list_registries_paginator: ListRegistriesPaginator = client.get_paginator("list_registries")
        list_schema_versions_paginator: ListSchemaVersionsPaginator = client.get_paginator("list_schema_versions")
        list_schemas_paginator: ListSchemasPaginator = client.get_paginator("list_schemas")
    ```







### Literals

`types_aiobotocore_glue.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_glue.literals import (
    BackfillErrorCodeType,
    BlueprintRunStateType,
    BlueprintStatusType,
    CatalogEncryptionModeType,
    CloudWatchEncryptionModeType,
    ColumnStatisticsTypeType,
    ComparatorType,
    CompatibilityType,
    ConnectionPropertyKeyType,
    ConnectionTypeType,
    CrawlStateType,
    CrawlerLineageSettingsType,
    CrawlerStateType,
    CsvHeaderOptionType,
    DataFormatType,
    DeleteBehaviorType,
    EnableHybridValuesType,
    ExistConditionType,
    GetClassifiersPaginatorName,
    GetConnectionsPaginatorName,
    GetCrawlerMetricsPaginatorName,
    GetCrawlersPaginatorName,
    GetDatabasesPaginatorName,
    GetDevEndpointsPaginatorName,
    GetJobRunsPaginatorName,
    GetJobsPaginatorName,
    GetPartitionIndexesPaginatorName,
    GetPartitionsPaginatorName,
    GetResourcePoliciesPaginatorName,
    GetSecurityConfigurationsPaginatorName,
    GetTableVersionsPaginatorName,
    GetTablesPaginatorName,
    GetTriggersPaginatorName,
    GetUserDefinedFunctionsPaginatorName,
    JobBookmarksEncryptionModeType,
    JobRunStateType,
    LanguageType,
    LastCrawlStatusType,
    ListRegistriesPaginatorName,
    ListSchemaVersionsPaginatorName,
    ListSchemasPaginatorName,
    LogicalOperatorType,
    LogicalType,
    MLUserDataEncryptionModeStringType,
    NodeTypeType,
    PartitionIndexStatusType,
    PermissionType,
    PermissionTypeType,
    PrincipalTypeType,
    RecrawlBehaviorType,
    RegistryStatusType,
    ResourceShareTypeType,
    ResourceTypeType,
    S3EncryptionModeType,
    ScheduleStateType,
    SchemaDiffTypeType,
    SchemaStatusType,
    SchemaVersionStatusType,
    SortDirectionTypeType,
    SortType,
    TaskRunSortColumnTypeType,
    TaskStatusTypeType,
    TaskTypeType,
    TransformSortColumnTypeType,
    TransformStatusTypeType,
    TransformTypeType,
    TriggerStateType,
    TriggerTypeType,
    UpdateBehaviorType,
    WorkerTypeType,
    WorkflowRunStatusType,
    GlueServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)

def check_value(value: BackfillErrorCodeType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_glue.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_glue.type_defs import (
    ActionTypeDef,
    AuditContextTypeDef,
    BackfillErrorTypeDef,
    BatchCreatePartitionRequestRequestTypeDef,
    BatchCreatePartitionResponseTypeDef,
    BatchDeleteConnectionRequestRequestTypeDef,
    BatchDeleteConnectionResponseTypeDef,
    BatchDeletePartitionRequestRequestTypeDef,
    BatchDeletePartitionResponseTypeDef,
    BatchDeleteTableRequestRequestTypeDef,
    BatchDeleteTableResponseTypeDef,
    BatchDeleteTableVersionRequestRequestTypeDef,
    BatchDeleteTableVersionResponseTypeDef,
    BatchGetBlueprintsRequestRequestTypeDef,
    BatchGetBlueprintsResponseTypeDef,
    BatchGetCrawlersRequestRequestTypeDef,
    BatchGetCrawlersResponseTypeDef,
    BatchGetDevEndpointsRequestRequestTypeDef,
    BatchGetDevEndpointsResponseTypeDef,
    BatchGetJobsRequestRequestTypeDef,
    BatchGetJobsResponseTypeDef,
    BatchGetPartitionRequestRequestTypeDef,
    BatchGetPartitionResponseTypeDef,
    BatchGetTriggersRequestRequestTypeDef,
    BatchGetTriggersResponseTypeDef,
    BatchGetWorkflowsRequestRequestTypeDef,
    BatchGetWorkflowsResponseTypeDef,
    BatchStopJobRunErrorTypeDef,
    BatchStopJobRunRequestRequestTypeDef,
    BatchStopJobRunResponseTypeDef,
    BatchStopJobRunSuccessfulSubmissionTypeDef,
    BatchUpdatePartitionFailureEntryTypeDef,
    BatchUpdatePartitionRequestEntryTypeDef,
    BatchUpdatePartitionRequestRequestTypeDef,
    BatchUpdatePartitionResponseTypeDef,
    BinaryColumnStatisticsDataTypeDef,
    BlueprintDetailsTypeDef,
    BlueprintRunTypeDef,
    BlueprintTypeDef,
    BooleanColumnStatisticsDataTypeDef,
    CancelMLTaskRunRequestRequestTypeDef,
    CancelMLTaskRunResponseTypeDef,
    CatalogEntryTypeDef,
    CatalogImportStatusTypeDef,
    CatalogTargetTypeDef,
    CheckSchemaVersionValidityInputRequestTypeDef,
    CheckSchemaVersionValidityResponseTypeDef,
    ClassifierTypeDef,
    CloudWatchEncryptionTypeDef,
    CodeGenEdgeTypeDef,
    CodeGenNodeArgTypeDef,
    CodeGenNodeTypeDef,
    ColumnErrorTypeDef,
    ColumnImportanceTypeDef,
    ColumnRowFilterTypeDef,
    ColumnStatisticsDataTypeDef,
    ColumnStatisticsErrorTypeDef,
    ColumnStatisticsTypeDef,
    ColumnTypeDef,
    ConditionTypeDef,
    ConfusionMatrixTypeDef,
    ConnectionInputTypeDef,
    ConnectionPasswordEncryptionTypeDef,
    ConnectionTypeDef,
    ConnectionsListTypeDef,
    CrawlTypeDef,
    CrawlerMetricsTypeDef,
    CrawlerNodeDetailsTypeDef,
    CrawlerTargetsTypeDef,
    CrawlerTypeDef,
    CreateBlueprintRequestRequestTypeDef,
    CreateBlueprintResponseTypeDef,
    CreateClassifierRequestRequestTypeDef,
    CreateConnectionRequestRequestTypeDef,
    CreateCrawlerRequestRequestTypeDef,
    CreateCsvClassifierRequestTypeDef,
    CreateDatabaseRequestRequestTypeDef,
    CreateDevEndpointRequestRequestTypeDef,
    CreateDevEndpointResponseTypeDef,
    CreateGrokClassifierRequestTypeDef,
    CreateJobRequestRequestTypeDef,
    CreateJobResponseTypeDef,
    CreateJsonClassifierRequestTypeDef,
    CreateMLTransformRequestRequestTypeDef,
    CreateMLTransformResponseTypeDef,
    CreatePartitionIndexRequestRequestTypeDef,
    CreatePartitionRequestRequestTypeDef,
    CreateRegistryInputRequestTypeDef,
    CreateRegistryResponseTypeDef,
    CreateSchemaInputRequestTypeDef,
    CreateSchemaResponseTypeDef,
    CreateScriptRequestRequestTypeDef,
    CreateScriptResponseTypeDef,
    CreateSecurityConfigurationRequestRequestTypeDef,
    CreateSecurityConfigurationResponseTypeDef,
    CreateTableRequestRequestTypeDef,
    CreateTriggerRequestRequestTypeDef,
    CreateTriggerResponseTypeDef,
    CreateUserDefinedFunctionRequestRequestTypeDef,
    CreateWorkflowRequestRequestTypeDef,
    CreateWorkflowResponseTypeDef,
    CreateXMLClassifierRequestTypeDef,
    CsvClassifierTypeDef,
    DataCatalogEncryptionSettingsTypeDef,
    DataLakePrincipalTypeDef,
    DatabaseIdentifierTypeDef,
    DatabaseInputTypeDef,
    DatabaseTypeDef,
    DateColumnStatisticsDataTypeDef,
    DecimalColumnStatisticsDataTypeDef,
    DecimalNumberTypeDef,
    DeleteBlueprintRequestRequestTypeDef,
    DeleteBlueprintResponseTypeDef,
    DeleteClassifierRequestRequestTypeDef,
    DeleteColumnStatisticsForPartitionRequestRequestTypeDef,
    DeleteColumnStatisticsForTableRequestRequestTypeDef,
    DeleteConnectionRequestRequestTypeDef,
    DeleteCrawlerRequestRequestTypeDef,
    DeleteDatabaseRequestRequestTypeDef,
    DeleteDevEndpointRequestRequestTypeDef,
    DeleteJobRequestRequestTypeDef,
    DeleteJobResponseTypeDef,
    DeleteMLTransformRequestRequestTypeDef,
    DeleteMLTransformResponseTypeDef,
    DeletePartitionIndexRequestRequestTypeDef,
    DeletePartitionRequestRequestTypeDef,
    DeleteRegistryInputRequestTypeDef,
    DeleteRegistryResponseTypeDef,
    DeleteResourcePolicyRequestRequestTypeDef,
    DeleteSchemaInputRequestTypeDef,
    DeleteSchemaResponseTypeDef,
    DeleteSchemaVersionsInputRequestTypeDef,
    DeleteSchemaVersionsResponseTypeDef,
    DeleteSecurityConfigurationRequestRequestTypeDef,
    DeleteTableRequestRequestTypeDef,
    DeleteTableVersionRequestRequestTypeDef,
    DeleteTriggerRequestRequestTypeDef,
    DeleteTriggerResponseTypeDef,
    DeleteUserDefinedFunctionRequestRequestTypeDef,
    DeleteWorkflowRequestRequestTypeDef,
    DeleteWorkflowResponseTypeDef,
    DeltaTargetTypeDef,
    DevEndpointCustomLibrariesTypeDef,
    DevEndpointTypeDef,
    DoubleColumnStatisticsDataTypeDef,
    DynamoDBTargetTypeDef,
    EdgeTypeDef,
    EncryptionAtRestTypeDef,
    EncryptionConfigurationTypeDef,
    ErrorDetailTypeDef,
    ErrorDetailsTypeDef,
    EvaluationMetricsTypeDef,
    EventBatchingConditionTypeDef,
    ExecutionPropertyTypeDef,
    ExportLabelsTaskRunPropertiesTypeDef,
    FindMatchesMetricsTypeDef,
    FindMatchesParametersTypeDef,
    FindMatchesTaskRunPropertiesTypeDef,
    GetBlueprintRequestRequestTypeDef,
    GetBlueprintResponseTypeDef,
    GetBlueprintRunRequestRequestTypeDef,
    GetBlueprintRunResponseTypeDef,
    GetBlueprintRunsRequestRequestTypeDef,
    GetBlueprintRunsResponseTypeDef,
    GetCatalogImportStatusRequestRequestTypeDef,
    GetCatalogImportStatusResponseTypeDef,
    GetClassifierRequestRequestTypeDef,
    GetClassifierResponseTypeDef,
    GetClassifiersRequestGetClassifiersPaginateTypeDef,
    GetClassifiersRequestRequestTypeDef,
    GetClassifiersResponseTypeDef,
    GetColumnStatisticsForPartitionRequestRequestTypeDef,
    GetColumnStatisticsForPartitionResponseTypeDef,
    GetColumnStatisticsForTableRequestRequestTypeDef,
    GetColumnStatisticsForTableResponseTypeDef,
    GetConnectionRequestRequestTypeDef,
    GetConnectionResponseTypeDef,
    GetConnectionsFilterTypeDef,
    GetConnectionsRequestGetConnectionsPaginateTypeDef,
    GetConnectionsRequestRequestTypeDef,
    GetConnectionsResponseTypeDef,
    GetCrawlerMetricsRequestGetCrawlerMetricsPaginateTypeDef,
    GetCrawlerMetricsRequestRequestTypeDef,
    GetCrawlerMetricsResponseTypeDef,
    GetCrawlerRequestRequestTypeDef,
    GetCrawlerResponseTypeDef,
    GetCrawlersRequestGetCrawlersPaginateTypeDef,
    GetCrawlersRequestRequestTypeDef,
    GetCrawlersResponseTypeDef,
    GetDataCatalogEncryptionSettingsRequestRequestTypeDef,
    GetDataCatalogEncryptionSettingsResponseTypeDef,
    GetDatabaseRequestRequestTypeDef,
    GetDatabaseResponseTypeDef,
    GetDatabasesRequestGetDatabasesPaginateTypeDef,
    GetDatabasesRequestRequestTypeDef,
    GetDatabasesResponseTypeDef,
    GetDataflowGraphRequestRequestTypeDef,
    GetDataflowGraphResponseTypeDef,
    GetDevEndpointRequestRequestTypeDef,
    GetDevEndpointResponseTypeDef,
    GetDevEndpointsRequestGetDevEndpointsPaginateTypeDef,
    GetDevEndpointsRequestRequestTypeDef,
    GetDevEndpointsResponseTypeDef,
    GetJobBookmarkRequestRequestTypeDef,
    GetJobBookmarkResponseTypeDef,
    GetJobRequestRequestTypeDef,
    GetJobResponseTypeDef,
    GetJobRunRequestRequestTypeDef,
    GetJobRunResponseTypeDef,
    GetJobRunsRequestGetJobRunsPaginateTypeDef,
    GetJobRunsRequestRequestTypeDef,
    GetJobRunsResponseTypeDef,
    GetJobsRequestGetJobsPaginateTypeDef,
    GetJobsRequestRequestTypeDef,
    GetJobsResponseTypeDef,
    GetMLTaskRunRequestRequestTypeDef,
    GetMLTaskRunResponseTypeDef,
    GetMLTaskRunsRequestRequestTypeDef,
    GetMLTaskRunsResponseTypeDef,
    GetMLTransformRequestRequestTypeDef,
    GetMLTransformResponseTypeDef,
    GetMLTransformsRequestRequestTypeDef,
    GetMLTransformsResponseTypeDef,
    GetMappingRequestRequestTypeDef,
    GetMappingResponseTypeDef,
    GetPartitionIndexesRequestGetPartitionIndexesPaginateTypeDef,
    GetPartitionIndexesRequestRequestTypeDef,
    GetPartitionIndexesResponseTypeDef,
    GetPartitionRequestRequestTypeDef,
    GetPartitionResponseTypeDef,
    GetPartitionsRequestGetPartitionsPaginateTypeDef,
    GetPartitionsRequestRequestTypeDef,
    GetPartitionsResponseTypeDef,
    GetPlanRequestRequestTypeDef,
    GetPlanResponseTypeDef,
    GetRegistryInputRequestTypeDef,
    GetRegistryResponseTypeDef,
    GetResourcePoliciesRequestGetResourcePoliciesPaginateTypeDef,
    GetResourcePoliciesRequestRequestTypeDef,
    GetResourcePoliciesResponseTypeDef,
    GetResourcePolicyRequestRequestTypeDef,
    GetResourcePolicyResponseTypeDef,
    GetSchemaByDefinitionInputRequestTypeDef,
    GetSchemaByDefinitionResponseTypeDef,
    GetSchemaInputRequestTypeDef,
    GetSchemaResponseTypeDef,
    GetSchemaVersionInputRequestTypeDef,
    GetSchemaVersionResponseTypeDef,
    GetSchemaVersionsDiffInputRequestTypeDef,
    GetSchemaVersionsDiffResponseTypeDef,
    GetSecurityConfigurationRequestRequestTypeDef,
    GetSecurityConfigurationResponseTypeDef,
    GetSecurityConfigurationsRequestGetSecurityConfigurationsPaginateTypeDef,
    GetSecurityConfigurationsRequestRequestTypeDef,
    GetSecurityConfigurationsResponseTypeDef,
    GetTableRequestRequestTypeDef,
    GetTableResponseTypeDef,
    GetTableVersionRequestRequestTypeDef,
    GetTableVersionResponseTypeDef,
    GetTableVersionsRequestGetTableVersionsPaginateTypeDef,
    GetTableVersionsRequestRequestTypeDef,
    GetTableVersionsResponseTypeDef,
    GetTablesRequestGetTablesPaginateTypeDef,
    GetTablesRequestRequestTypeDef,
    GetTablesResponseTypeDef,
    GetTagsRequestRequestTypeDef,
    GetTagsResponseTypeDef,
    GetTriggerRequestRequestTypeDef,
    GetTriggerResponseTypeDef,
    GetTriggersRequestGetTriggersPaginateTypeDef,
    GetTriggersRequestRequestTypeDef,
    GetTriggersResponseTypeDef,
    GetUnfilteredPartitionMetadataRequestRequestTypeDef,
    GetUnfilteredPartitionMetadataResponseTypeDef,
    GetUnfilteredPartitionsMetadataRequestRequestTypeDef,
    GetUnfilteredPartitionsMetadataResponseTypeDef,
    GetUnfilteredTableMetadataRequestRequestTypeDef,
    GetUnfilteredTableMetadataResponseTypeDef,
    GetUserDefinedFunctionRequestRequestTypeDef,
    GetUserDefinedFunctionResponseTypeDef,
    GetUserDefinedFunctionsRequestGetUserDefinedFunctionsPaginateTypeDef,
    GetUserDefinedFunctionsRequestRequestTypeDef,
    GetUserDefinedFunctionsResponseTypeDef,
    GetWorkflowRequestRequestTypeDef,
    GetWorkflowResponseTypeDef,
    GetWorkflowRunPropertiesRequestRequestTypeDef,
    GetWorkflowRunPropertiesResponseTypeDef,
    GetWorkflowRunRequestRequestTypeDef,
    GetWorkflowRunResponseTypeDef,
    GetWorkflowRunsRequestRequestTypeDef,
    GetWorkflowRunsResponseTypeDef,
    GluePolicyTypeDef,
    GlueTableTypeDef,
    GrokClassifierTypeDef,
    ImportCatalogToGlueRequestRequestTypeDef,
    ImportLabelsTaskRunPropertiesTypeDef,
    JdbcTargetTypeDef,
    JobBookmarkEntryTypeDef,
    JobBookmarksEncryptionTypeDef,
    JobCommandTypeDef,
    JobNodeDetailsTypeDef,
    JobRunTypeDef,
    JobTypeDef,
    JobUpdateTypeDef,
    JsonClassifierTypeDef,
    KeySchemaElementTypeDef,
    LabelingSetGenerationTaskRunPropertiesTypeDef,
    LakeFormationConfigurationTypeDef,
    LastActiveDefinitionTypeDef,
    LastCrawlInfoTypeDef,
    LineageConfigurationTypeDef,
    ListBlueprintsRequestRequestTypeDef,
    ListBlueprintsResponseTypeDef,
    ListCrawlersRequestRequestTypeDef,
    ListCrawlersResponseTypeDef,
    ListDevEndpointsRequestRequestTypeDef,
    ListDevEndpointsResponseTypeDef,
    ListJobsRequestRequestTypeDef,
    ListJobsResponseTypeDef,
    ListMLTransformsRequestRequestTypeDef,
    ListMLTransformsResponseTypeDef,
    ListRegistriesInputListRegistriesPaginateTypeDef,
    ListRegistriesInputRequestTypeDef,
    ListRegistriesResponseTypeDef,
    ListSchemaVersionsInputListSchemaVersionsPaginateTypeDef,
    ListSchemaVersionsInputRequestTypeDef,
    ListSchemaVersionsResponseTypeDef,
    ListSchemasInputListSchemasPaginateTypeDef,
    ListSchemasInputRequestTypeDef,
    ListSchemasResponseTypeDef,
    ListTriggersRequestRequestTypeDef,
    ListTriggersResponseTypeDef,
    ListWorkflowsRequestRequestTypeDef,
    ListWorkflowsResponseTypeDef,
    LocationTypeDef,
    LongColumnStatisticsDataTypeDef,
    MLTransformTypeDef,
    MLUserDataEncryptionTypeDef,
    MappingEntryTypeDef,
    MetadataInfoTypeDef,
    MetadataKeyValuePairTypeDef,
    MongoDBTargetTypeDef,
    NodeTypeDef,
    NotificationPropertyTypeDef,
    OrderTypeDef,
    OtherMetadataValueListItemTypeDef,
    PaginatorConfigTypeDef,
    PartitionErrorTypeDef,
    PartitionIndexDescriptorTypeDef,
    PartitionIndexTypeDef,
    PartitionInputTypeDef,
    PartitionTypeDef,
    PartitionValueListTypeDef,
    PhysicalConnectionRequirementsTypeDef,
    PredecessorTypeDef,
    PredicateTypeDef,
    PrincipalPermissionsTypeDef,
    PropertyPredicateTypeDef,
    PutDataCatalogEncryptionSettingsRequestRequestTypeDef,
    PutResourcePolicyRequestRequestTypeDef,
    PutResourcePolicyResponseTypeDef,
    PutSchemaVersionMetadataInputRequestTypeDef,
    PutSchemaVersionMetadataResponseTypeDef,
    PutWorkflowRunPropertiesRequestRequestTypeDef,
    QuerySchemaVersionMetadataInputRequestTypeDef,
    QuerySchemaVersionMetadataResponseTypeDef,
    RecrawlPolicyTypeDef,
    RegisterSchemaVersionInputRequestTypeDef,
    RegisterSchemaVersionResponseTypeDef,
    RegistryIdTypeDef,
    RegistryListItemTypeDef,
    RemoveSchemaVersionMetadataInputRequestTypeDef,
    RemoveSchemaVersionMetadataResponseTypeDef,
    ResetJobBookmarkRequestRequestTypeDef,
    ResetJobBookmarkResponseTypeDef,
    ResourceUriTypeDef,
    ResponseMetadataTypeDef,
    ResumeWorkflowRunRequestRequestTypeDef,
    ResumeWorkflowRunResponseTypeDef,
    S3EncryptionTypeDef,
    S3TargetTypeDef,
    ScheduleTypeDef,
    SchemaChangePolicyTypeDef,
    SchemaColumnTypeDef,
    SchemaIdTypeDef,
    SchemaListItemTypeDef,
    SchemaReferenceTypeDef,
    SchemaVersionErrorItemTypeDef,
    SchemaVersionListItemTypeDef,
    SchemaVersionNumberTypeDef,
    SearchTablesRequestRequestTypeDef,
    SearchTablesResponseTypeDef,
    SecurityConfigurationTypeDef,
    SegmentTypeDef,
    SerDeInfoTypeDef,
    SkewedInfoTypeDef,
    SortCriterionTypeDef,
    StartBlueprintRunRequestRequestTypeDef,
    StartBlueprintRunResponseTypeDef,
    StartCrawlerRequestRequestTypeDef,
    StartCrawlerScheduleRequestRequestTypeDef,
    StartExportLabelsTaskRunRequestRequestTypeDef,
    StartExportLabelsTaskRunResponseTypeDef,
    StartImportLabelsTaskRunRequestRequestTypeDef,
    StartImportLabelsTaskRunResponseTypeDef,
    StartJobRunRequestRequestTypeDef,
    StartJobRunResponseTypeDef,
    StartMLEvaluationTaskRunRequestRequestTypeDef,
    StartMLEvaluationTaskRunResponseTypeDef,
    StartMLLabelingSetGenerationTaskRunRequestRequestTypeDef,
    StartMLLabelingSetGenerationTaskRunResponseTypeDef,
    StartTriggerRequestRequestTypeDef,
    StartTriggerResponseTypeDef,
    StartWorkflowRunRequestRequestTypeDef,
    StartWorkflowRunResponseTypeDef,
    StartingEventBatchConditionTypeDef,
    StopCrawlerRequestRequestTypeDef,
    StopCrawlerScheduleRequestRequestTypeDef,
    StopTriggerRequestRequestTypeDef,
    StopTriggerResponseTypeDef,
    StopWorkflowRunRequestRequestTypeDef,
    StorageDescriptorTypeDef,
    StringColumnStatisticsDataTypeDef,
    TableErrorTypeDef,
    TableIdentifierTypeDef,
    TableInputTypeDef,
    TableTypeDef,
    TableVersionErrorTypeDef,
    TableVersionTypeDef,
    TagResourceRequestRequestTypeDef,
    TaskRunFilterCriteriaTypeDef,
    TaskRunPropertiesTypeDef,
    TaskRunSortCriteriaTypeDef,
    TaskRunTypeDef,
    TransformEncryptionTypeDef,
    TransformFilterCriteriaTypeDef,
    TransformParametersTypeDef,
    TransformSortCriteriaTypeDef,
    TriggerNodeDetailsTypeDef,
    TriggerTypeDef,
    TriggerUpdateTypeDef,
    UnfilteredPartitionTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateBlueprintRequestRequestTypeDef,
    UpdateBlueprintResponseTypeDef,
    UpdateClassifierRequestRequestTypeDef,
    UpdateColumnStatisticsForPartitionRequestRequestTypeDef,
    UpdateColumnStatisticsForPartitionResponseTypeDef,
    UpdateColumnStatisticsForTableRequestRequestTypeDef,
    UpdateColumnStatisticsForTableResponseTypeDef,
    UpdateConnectionRequestRequestTypeDef,
    UpdateCrawlerRequestRequestTypeDef,
    UpdateCrawlerScheduleRequestRequestTypeDef,
    UpdateCsvClassifierRequestTypeDef,
    UpdateDatabaseRequestRequestTypeDef,
    UpdateDevEndpointRequestRequestTypeDef,
    UpdateGrokClassifierRequestTypeDef,
    UpdateJobRequestRequestTypeDef,
    UpdateJobResponseTypeDef,
    UpdateJsonClassifierRequestTypeDef,
    UpdateMLTransformRequestRequestTypeDef,
    UpdateMLTransformResponseTypeDef,
    UpdatePartitionRequestRequestTypeDef,
    UpdateRegistryInputRequestTypeDef,
    UpdateRegistryResponseTypeDef,
    UpdateSchemaInputRequestTypeDef,
    UpdateSchemaResponseTypeDef,
    UpdateTableRequestRequestTypeDef,
    UpdateTriggerRequestRequestTypeDef,
    UpdateTriggerResponseTypeDef,
    UpdateUserDefinedFunctionRequestRequestTypeDef,
    UpdateWorkflowRequestRequestTypeDef,
    UpdateWorkflowResponseTypeDef,
    UpdateXMLClassifierRequestTypeDef,
    UserDefinedFunctionInputTypeDef,
    UserDefinedFunctionTypeDef,
    WorkflowGraphTypeDef,
    WorkflowRunStatisticsTypeDef,
    WorkflowRunTypeDef,
    WorkflowTypeDef,
    XMLClassifierTypeDef,
)

def get_structure() -> ActionTypeDef:
    return {
      ...
    }
```

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

## What's new

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

## Versioning

`types-aiobotocore-glue` version is the same as related `aiobotocore` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_glue/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
